@@ -38,6 +38,8 @@
 #' codes is returned, sorted by the state's abbreviation (e.g. Alaska (AK) comes
 #' before Alabama (AL)).
 #'
+#' @seealso [fips_info()]
+#'
 #' @examples
 #' fips()
 #'
@@ -52,14 +54,14 @@
 #' @export
 fips <- function(state, county = c()) {
   if (missing(state) && missing(county)) {
-    return(usmapdata::fips_data()$fips)
+    return(usmapdata::fips_data(as_sf = TRUE)$fips)
   }
 
   state_ <- tolower(state)
   county_ <- tolower(county)
 
   if (length(county_) == 0) {
-    df <- usmapdata::fips_data()
+    df <- usmapdata::fips_data(as_sf = TRUE)
     abbr <- tolower(df$abbr)
     full <- tolower(df$full)
     fips2 <- c(df$fips, df$fips)
@@ -72,7 +74,7 @@ fips <- function(state, county = c()) {
       stop("`county` parameter cannot be used with multiple states.")
     }
 
-    df <- usmapdata::fips_data("counties")
+    df <- usmapdata::fips_data("counties", as_sf = TRUE)
     name <- tolower(df$county)
     state_abbr <- tolower(df$abbr)
     state_full <- tolower(df$full)
@@ -119,6 +121,8 @@ fips <- function(state, county = c()) {
 #'  If `fips` is omitted, the data frame containing all available states is
 #'  returned.
 #'
+#' @seealso [fips()]
+#'
 #' @examples
 #' fips_info(2)
 #' fips_info("2")
@@ -166,14 +170,14 @@ fips_info.character <- function(fips, sortAndRemoveDuplicates = FALSE) {
 }
 
 #' Gets FIPS info for either states or counties depending on input.
-#' Helper function for S3 method \code{fips_info}.
+#' Helper function for S3 method [fips_info()].
 #' @keywords internal
 get_fips_info <- function(fips, sortAndRemoveDuplicates) {
   if (all(nchar(fips) == 2)) {
-    df <- usmapdata::fips_data()
+    df <- usmapdata::fips_data(as_sf = TRUE)
     columns <- c("abbr", "fips", "full")
   } else if (all(nchar(fips) == 5)) {
-    df <- usmapdata::fips_data("counties")
+    df <- usmapdata::fips_data("counties", as_sf = TRUE)
     columns <- c("full", "abbr", "county", "fips")
   }
 
@@ -196,9 +200,11 @@ get_fips_info <- function(fips, sortAndRemoveDuplicates) {
   result[, columns]
 }
 
-#' Performs merge while maintaining original sort order.
+#' Merge while maintaining original sort order
 #'
-#' @seealso https://stackoverflow.com/a/61560405/7264964
+#' Internal function used by [fips_info()].
+#'
+#' @seealso \url{https://stackoverflow.com/a/61560405/7264964}
 #' @keywords internal
 static_merge <- function(x, y, ...) {
   x$join_id_ <- seq_len(nrow(x))
