@@ -3,13 +3,13 @@
 #' @description
 #' It is usually difficult or inconvenient to create US maps that
 #'   include both Alaska and Hawaii in a convenient spot. All map
-#'   data frames produced by this package use the Albers Equal Area
+#'   data presented in this package uses the US National Atlas Equal Area
 #'   projection.
 #'
-#' @section Map data frames:
+#' @section Map data:
 #' Alaska and Hawaii have been manually moved to a new location so that
 #' their new coordinates place them to the bottom-left corner of
-#' the map. These maps can be accessed by using the [us_map] function.
+#' the map. These maps can be accessed by using the [us_map()] function.
 #'
 #' The function provides the ability to retrieve maps with either
 #' state borders or county borders using the \code{regions} parameter
@@ -29,12 +29,18 @@
 #' preparing data to be merged with the map data frame.
 #'
 #' @section Plot US map data:
-#' A convenience function [plot_usmap] has been included which
-#' takes similar parameters to [us_map] and returns a [ggplot2::ggplot2]
+#' A convenience function [plot_usmap()] has been included which
+#' takes similar parameters to [us_map()] and returns a [ggplot2::ggplot2]
 #' object. Since the output is a \code{ggplot} object, other layers can be
 #' added such as scales, themes, and labels. Including data in the function call
 #' will color the map according to the values in the data, creating a choropleth.
 #'
+#' @section Transforming data:
+#' It is also possible to add spatial data to the map, in the form of either
+#' data frames or simple features ([sf::sf]) objects. If necessary, the
+#' data can be transformed to be in the same coordinate reference system as
+#' [usmap] by using [usmap_transform()] and then plotted using [ggplot2::geom_sf()].
+#'
 #' @author Paolo Di Lorenzo \cr
 #' \itemize{
 #'   \item Email: \email{dilorenzo@@hey}
@@ -50,9 +56,10 @@
 #'   \item US Census Shapefiles \cr
 #'     \url{https://www.census.gov/geographies/mapping-files/time-series/geo/cartographic-boundary.html}
 #'   \item Map Features \cr
-#'     \url{https://en.wikipedia.org/wiki/Map_projection}
-#'     \url{https://en.wikipedia.org/wiki/Albers_projection}
-#'     \url{https://en.wikipedia.org/wiki/Choropleth}
+#'     \url{https://en.wikipedia.org/wiki/Map_projection} \cr
+#'     \url{https://en.wikipedia.org/wiki/Equal-area_projection} \cr
+#'     \url{https://en.wikipedia.org/wiki/Choropleth} \cr
+#'     \url{https://epsg.io/9311} (US National Atlas Equal Area)
 #' }
 #'
 #' @references
@@ -96,11 +103,5 @@
 us_map <- function(regions = c("states", "state", "counties", "county"),
                    include = c(),
                    exclude = c()) {
-  # check for usmapdata
-  if (!requireNamespace("usmapdata", quietly = TRUE)) {
-    stop("`usmapdata` must be installed to use `plot_usmap`.
-         Use: install.packages(\"usmapdata\") and try again.")
-  }
-
-  usmapdata::us_map(regions = regions, include = include, exclude = exclude)
+  usmapdata::us_map(regions = regions, include = include, exclude = exclude, as_sf = TRUE)
 }
